==> odoo_19.0.20251025.zip: odoo-19.0.post20251025/odoo/addons/project_todo/static/src/views/todo_form/todo_form_control_panel.js <==
import { onMounted, useEffect } from "@odoo/owl";
import { browser } from "@web/core/browser/browser";
import { router } from "@web/core/browser/router";
import { ControlPanel } from "@web/search/control_panel/control_panel";

export class TodoFormControlPanel extends ControlPanel {
    static template = "project_todo.TodoFormControlPanel";

    setup() {
        super.setup();
        useEffect(
            (isSmall) => {
                if (isSmall && !this.state.displayChatter) {
                    this.toggleChatter();
                }
            },
            () => [this.env.isSmall]
        );
        onMounted(() => {
            // We check if we have come from activity view using router action stack and toggle chatter
            const isFromActivityView =
                router.current.actionStack?.[router.current.actionStack?.length - 1]?.view_type ===
                "activity";
            if (
                !this.env.isSmall &&
                !this.state.displayChatter &&
                (isFromActivityView || JSON.parse(browser.localStorage.getItem("isChatterOpened")))
            ) {
                this.toggleChatter();
            }
        });
    }

    toggleChatter(ev) {
        this.state.displayChatter = !this.state.displayChatter;
        if (ev) {
            browser.localStorage.setItem("isChatterOpened", this.state.displayChatter);
        }
        this.env.bus.trigger("TODO:TOGGLE_CHATTER", { displayChatter: this.state.displayChatter });
    }
}

==> odoo_19.3a1.20260226.zip: odoo-19.3a1.post20260226/odoo/addons/project_todo/static/src/views/todo_form/todo_form_control_panel.js <==
import { useLayoutEffect } from "@web/owl2/utils";
import { onMounted } from "@odoo/owl";
import { browser } from "@web/core/browser/browser";
import { router } from "@web/core/browser/router";
import { ControlPanel } from "@web/search/control_panel/control_panel";

export class TodoFormControlPanel extends ControlPanel {
    static template = "project_todo.TodoFormControlPanel";

    setup() {
        super.setup();
        useLayoutEffect(
            (isSmall) => {
                if (isSmall && !this.state.displayChatter) {
                    this.toggleChatter();
                }
            },
            () => [this.env.isSmall]
        );
        onMounted(() => {
            // We check if we have come from activity view using router action stack and toggle chatter
            const isFromActivityView =
                router.current.actionStack?.[router.current.actionStack?.length - 1]?.view_type ===
                "activity";
            if (
                !this.env.isSmall &&
                !this.state.displayChatter &&
                (isFromActivityView || JSON.parse(browser.localStorage.getItem("isChatterOpened")))
            ) {
                this.toggleChatter();
            }
        });
    }

    toggleChatter(ev) {
        this.state.displayChatter = !this.state.displayChatter;
        if (ev) {
            browser.localStorage.setItem("isChatterOpened", this.state.displayChatter);
        }
        this.env.bus.trigger("TODO:TOGGLE_CHATTER", { displayChatter: this.state.displayChatter });
    }
}
